@@ -5,7 +5,7 @@
 #  ALL RIGHTS RESERVED.
 #
 #  Authors: Vasya Svintsov <v.svintsov@techokert.ru>
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Any
 
 from init_helpers.dict_to_dataclass import convert_to_type
@@ -14,7 +14,17 @@ from init_helpers.dict_to_dataclass import convert_to_type
 @dataclass
 class EntityOrder:
     column: str
-    ascending: bool = True
+    ascending: bool
+
+
+@dataclass
+class EntityOrderASC(EntityOrder):
+    ascending: bool = field(init=False, default=True)
+
+
+@dataclass
+class EntityOrderDESC(EntityOrder):
+    ascending: bool = field(init=False, default=False)
 
 
 def entity_order_as_dict(order: EntityOrder) -> dict[str, Any]:
